@@ -1,6 +1,6 @@
 /*
  * AJD4JP
- * Copyright (c) 2011  Akira Terasaki
+ * Copyright (c) 2011-2014  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -254,6 +254,10 @@ public enum Holiday implements OffProvider.Off {
 	MEIJI(
 		new FixHoliday( "明治天皇祭", new Holy( 1913, 7, 30 ), new Holy( 1926, 7, 30 ) )
 	),
+	/** 山の日 */
+	YAMA(
+		new FixHoliday( "山の日", new Holy( 2016, 8, 11 ), null )
+	),
 	/** <s>天長節(大正天皇)</s> */
 	TAISHO(
 		new FixHoliday( "天長節", new Holy( 1913, 8, 31 ), new Holy( 1926, 8, 31 ) )
