@@ -1,6 +1,6 @@
 /*
  * AJD4JP
- * Copyright (c) 2011  Akira Terasaki
+ * Copyright (c) 2011-2015  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -122,8 +122,8 @@ public class LunisolarYear implements Comparable<LunisolarYear>, java.io.Seriali
 			year--;
 			if ( year == 0 )	year--;
 		}
-		AJD[]	toji = new AJD[4];
 		int	yyyy = year - 1;
+		AJD[]	toji = new AJD[4];
 		if ( yyyy == 0 )	yyyy--;
 		for ( int i = 0; i < toji.length; i++ ) {
 			toji[i] = STCD.getStart( yyyy, START );
@@ -199,8 +199,8 @@ public class LunisolarYear implements Comparable<LunisolarYear>, java.io.Seriali
 			list.add( saku[mid[1]] );
 		}
 		for ( int i = 0; i < line[2].length; i++ ) {
-			if ( line[2][i].year != year )	break;
 			list.add( line[2][i] );
+			if ( line[2][i].year != year )	break;
 		}
 		int	cnt = list.size();
 		for ( int i = 1; i < cnt; i++ ) {
@@ -218,7 +218,7 @@ public class LunisolarYear implements Comparable<LunisolarYear>, java.io.Seriali
 
 	/**
 	 * 旧暦の年の取得。
-	 * 新暦と旧暦は年始が数日ずれるため、同じ年でない場合があります。
+	 * 新暦と旧暦は年始がずれるため、同じ年でない場合があります。
 	 * @param hint この日付が含まれる年を返す。
 	 * @return hintが含まれる年。
 	 */
@@ -273,6 +273,15 @@ public class LunisolarYear implements Comparable<LunisolarYear>, java.io.Seriali
 			mine.add( s );
 		}
 		month = mine.toArray( new Saku[0] );
+		if (limit == null) {
+			int ny = y + 1;
+			if (ny == 0) { ny = 1; }
+			LunisolarYear next = null;
+			try {
+				next = getLunisolarYear(ny);
+			} catch(AJDException e){}
+			limit = next.month[0];
+		}
 	}
 
 	/**
@@ -290,8 +299,12 @@ public class LunisolarYear implements Comparable<LunisolarYear>, java.io.Seriali
 	 */
 	public LSCD getLSCD( AJD dd ) {
 		AJD	ajd = dd.trim();
-		if ( ajd.compareTo( month[0].ajd ) < 0 )	return null;
-		if ( ajd.compareTo( limit.ajd ) >= 0 )	return null;
+		if ( ajd.compareTo( month[0].ajd ) < 0 ) {
+			return null;
+		}
+		if ( ajd.compareTo( limit.ajd ) >= 0 ) {
+			return null;
+		}
 		int	i = 1;
 		for ( ; i < month.length; i++ ) {
 			if ( ajd.compareTo( month[i].ajd ) < 0 )	break;
