@@ -1,6 +1,6 @@
 /*
  * AJD4JP
- * Copyright (c) 2011  Akira Terasaki
+ * Copyright (c) 2011-2015  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -46,6 +46,53 @@ public class STCD implements Day {
 		}
 	}
 
+	/**
+	 * 土用。
+	 */
+	public enum Doyo {
+		/** 冬。 */
+		WINTER(315),
+		/** 春。 */
+		SPRING(45),
+		/** 夏。 */
+		SUMMER(135),
+		/** 秋。 */
+		AUTUMN(225);
+		private int start, end;
+		private Doyo(int r) {
+			start = r - 18;
+			end = r;
+		}
+
+		/**
+		 * 土用の期間を返します。土用最終日が節分となります。
+		 * @param year 取得したい西暦年。節月の年ではありません。
+		 * @param filter 特定の干支のみ(例えば丑)必要な場合に指定します。
+		 * 無指定ならば全ての土用を返します。
+		 * @return 土用の全日程。
+		 * @exception AJDException 年の指定に誤りがある場合。
+		 */
+		public AJD[] getDoyo(int year, EarthlyBranch ... filter) throws AJDException {
+			AJD.check(year, 1);
+			AJD[] ajd = new AJD[] {
+				getStart(year, start), getStart(year, end)
+			};
+			ArrayList<AJD> list = new ArrayList<AJD>();
+			for (AJD k = ajd[0]; k.compareTo(ajd[1]) < 0; k = k.addDay(1)) {
+				boolean hit = filter.length == 0;
+				for (EarthlyBranch f: filter) {
+					if (EarthlyBranch.getDay(k) == f) {
+						hit = true;
+						break;
+					}
+				}
+				if (hit) { list.add(k); }
+			}
+			return list.toArray(new AJD[0]);
+		}
+
+	}
+
 	private AJD	ajd;
 	private int yy, mm, dd;
 	/**
